/* Copyright 2006 Siva Dirisala */
import java.awt.event.*;
import javax.swing.*;

public class Clock extends JButton implements ActionListener {

  public Clock() {
    t = new Timer(1000,this);
    setHorizontalAlignment(SwingConstants.CENTER);
    addActionListener(this);
    paused = false;
  }

  public void actionPerformed(ActionEvent e) {
    seconds++;
    setText(toString(seconds));
    repaint();
  }

  public String toString(int seconds) {
    int h = seconds/3600;
    int m = (seconds-h*3600)/60;
    int s = (seconds-h*3600-m*60);
    buf.delete(0,buf.length());
    buf.append(h);
    buf.append(':');
    buf.append(m);
    buf.append(':');
    buf.append(s);
    return buf.toString();
  }

  public boolean isPaused() {
    return paused;
  }

  public boolean pause() {
    if(paused) {
      if(!t.isRunning()) {
        t.start();
        paused = !paused;
	return true;
      }
    }
    else if(t.isRunning()) {
      t.stop();
      paused = !paused;
      return true;
    }
    return false;
  }

  public void restart() {
    seconds = 0;
    paused = false;
    t.restart();
  }

  public void start() {
    t.start();
  }

  public void stop() {
    t.stop();
  }

  public boolean isRunning() { 
    return t.isRunning();
  }

  protected Timer t;
  protected int seconds;
  protected boolean paused;
  private StringBuilder buf = new StringBuilder(8);
}
